@@ -259,7 +259,7 @@ typedef unsigned char option_mask [16];
 void parse_options PROTO ((struct packet *));
 void parse_option_buffer PROTO ((struct packet *, unsigned char *, int));
 void cons_options PROTO ((struct packet *, struct packet *,
-			  struct tree_cache **, int, int));
+			  struct tree_cache **, int, int, int));
 int store_options PROTO ((unsigned char *, int, struct tree_cache **,
 			   unsigned char *, int, int, int, int));
 char *pretty_print_option PROTO ((unsigned char, unsigned char *, int));
@@ -501,7 +501,7 @@ extern struct interface_info *interfaces;
 void discover_interfaces PROTO ((int));
 void dispatch PROTO ((void));
 void do_packet PROTO ((struct interface_info *,
-		       unsigned char *, int,
+		       struct dhcp_packet *, int,
 		       unsigned short, struct iaddr, struct hardware *));
 int locate_network PROTO ((struct packet *));
 
